@@ -8,8 +8,11 @@ from zope.interface import implements, Interface
 
 from Acquisition import aq_inner
 
-from zope.container.interfaces import INameChooser
 from zope import component
+try:
+    from zope.container.interfaces import INameChooser
+except ImportError:
+    from zope.app.container.interfaces import INameChooser
 
 from Products.CMFCore.utils import getToolByName
 from Products.Five.browser import BrowserView
